/// <reference types="node" />
import * as tough from 'tough-cookie';
import Album from './Album';
import Photo from './Photo';
export interface GPhotosConstructorParams {
    username?: string;
    password?: string;
    options?: Partial<GPhotosOptions>;
}
export interface GPhotosOptions {
    progress: boolean;
    jar: tough.CookieJar;
}
export interface GPhotosParams {
    at: string;
    userId: string;
}
declare class GPhotos {
    private username?;
    private password?;
    private options;
    private axios;
    private params;
    /**
     * @example
     * ```js
     * const gphotos = new GPhotos({
     *   username: 'username@gmail.com',
     *   password: 'YOUR_PASSWORD',
     *   options: {
     *     progress: true,
     *   }
     * });
     * ```
     */
    constructor(params: GPhotosConstructorParams);
    /** @private */
    sendBatchExecute(queries: Record<string, any>): Promise<any>;
    /** @private */
    sendQuery(url: string, query: any): Promise<any>;
    /**
     * @example
     * ```js
     * gphotos.login()
     *   .then((gphotos) => {
     *     // do something
     *   })
     *   .catch((err) => {
     *     console.error(err.stack);
     *   });
     * ```
     */
    login(): Promise<this>;
    /** @private */
    postLogin(): Promise<void>;
    /** @private */
    fetchParams(): Promise<{
        at: string;
        userId: string;
    }>;
    searchAlbum(albumName: string | number): Promise<Album>;
    fetchAllAlbumList(): Promise<Album[]>;
    fetchAlbumList(next?: string): Promise<{
        list: Album[];
        next?: string;
    }>;
    createAlbum(albumName: string): Promise<Album>;
    fetchPhotoById(id: string): Promise<Photo>;
    fetchAllPhotoList(): Promise<Photo[]>;
    fetchPhotoList(next?: string): Promise<{
        list: never[];
        next: undefined;
    } | {
        list: Photo[];
        next: string;
    }>;
    fetchLatestPhoto(): Promise<Photo>;
    searchOrCreateAlbum(albumName: string): Promise<Album>;
    upload(filePath: string, _fileName?: string): Promise<Photo>;
    uploadFromStream(stream: NodeJS.ReadableStream, size: number, fileName?: string): Promise<Photo>;
}
export default GPhotos;
